{ pkgs ? import <nixpkgs> {} }:

pkgs.mkShell {
  buildInputs = with pkgs; [
    nodejs_24
    nodePackages.pnpm
    chromium
    git
    curl
  ];

  shellHook = ''
    echo "🚀 atridotdad development environment loaded!"
    echo "Node version: $(node --version)"
    echo "pnpm version: $(pnpm --version)"
    echo "Chromium path: ${pkgs.chromium}/bin/chromium"
    
    # Playwright environment variables
    export PLAYWRIGHT_SKIP_BROWSER_DOWNLOAD=1
    export PLAYWRIGHT_CHROMIUM_EXECUTABLE_PATH="${pkgs.chromium}/bin/chromium"
    
    # Keep old Puppeteer vars for compatibility (in case you have other code using it)
    export PUPPETEER_SKIP_CHROMIUM_DOWNLOAD=true
    export PUPPETEER_EXECUTABLE_PATH="${pkgs.chromium}/bin/chromium"
    
    if [ ! -d "node_modules" ]; then
      echo "📦 Installing dependencies..."
      pnpm install
    fi
  '';

  # Environment variables
  PLAYWRIGHT_SKIP_BROWSER_DOWNLOAD = "1";
  PLAYWRIGHT_CHROMIUM_EXECUTABLE_PATH = "${pkgs.chromium}/bin/chromium";
  PUPPETEER_SKIP_CHROMIUM_DOWNLOAD = "true";
  PUPPETEER_EXECUTABLE_PATH = "${pkgs.chromium}/bin/chromium";
}